# Descriptive Statistics and Hypothesis Tests

The goal of this library is to provide a common interface for existing hypothesis tests across several frameworks as well as implement some new ones.  Additionally this library is here to provide a set of descriptive statistics that may be overlooked.

## Implemented Notions

* Timeseries Data

This is data with a timeseries component, therefore this data is collected over time.  Time will be one of the variables collected, on some scale

* Geo Spatial Data

This is data with a geospatial component, therefore this data is collected with coordinates of some kind.  It is likely latitude and longitude or some variant there of will be present in data sets of this kind.

* Typical Data 

This is data without time or geospatial structure.  For now it is the blanket for all other data.  If a better name is decided upon, it will be used in this names place.

